@@ -13,7 +13,7 @@ def _config_filepath():
 
 def _noLoginMessage():
     print(" you have not set your account yet, set your account with:\n")
-    print("  tla config <access_key> <secret_key> [host] \n")
+    print("  tla config <access_key> [host] \n")
     print(" more about this command, use：\n")
     print("  tla config --help")
     exit()
