@@ -19,6 +19,7 @@ def _download(url, savePath):
     with open(savePath, 'wb') as f:
         f.write(res.content)
 
+
 def printVersion(ctx):
     if hasattr(testinlabel, "VERSION"):
         click.echo("")
@@ -39,9 +40,18 @@ def printVersion(ctx):
 
 
 @click.group()
-@click.option("-ak", "--accessKey", 'access_key', default="", help="access key to Testin annotation system, see: http://label.testin.cn/v/secret-key")
+@click.option("-ak",
+              "--accessKey",
+              'access_key',
+              default="",
+              help="access key to Testin annotation system, see: http://label.testin.cn/v/secret-key")
 # @click.option("-sk", "--secretKey", 'secret_key', default="")
-@click.option("-h", "--host", 'host', default="http://label.testin.cn/", help="domain name that access to annotation system you would like to operate, default will be: https://label.testin.cn/")
+@click.option(
+    "-h",
+    "--host",
+    'host',
+    default="http://label.testin.cn/",
+    help="domain name that access to annotation system you would like to operate, default will be: https://label.testin.cn/")
 @click.option('--debug/--no-debug', default=True, help="using debug mod or not, default is False")
 @click.pass_context
 def main(ctx, access_key, host, debug):
@@ -72,6 +82,7 @@ def main(ctx, access_key, host, debug):
 
     ctx.obj = _tla
 
+
 @main.command()
 @click.option("-k", "--task-key", 'taskKey', default="", required=True, help="the task you wolud like to oprate")
 @click.pass_context
@@ -87,7 +98,7 @@ def template(ctx, taskKey):
         click.echo("  tla config --help")
         exit()
 
-    codeContent=f"""from testinlabel.exportAbstract import ExportAbstract # warning: don't edit this line and don't change the script name!!!
+    codeContent = f"""from testinlabel.exportAbstract import ExportAbstract # warning: don't edit this line and don't change the script name!!!
 from testinlabel.TLA import TLA     # warning: don't edit this line and don't change the script name!!!
 
 #import your packages
@@ -149,6 +160,7 @@ def export(ctx, file):
     ex.exec()
     click.echo("done!")
 
+
 @main.command()
 @click.pass_context
 def version(ctx):
@@ -158,9 +170,18 @@ def version(ctx):
 
 
 @main.command()
-@click.option("-ak", "--accessKey", 'access_key', default="", help="access key to Testin annotation system, see: http://label.testin.cn/v/secret-key")
+@click.option("-ak",
+              "--accessKey",
+              'access_key',
+              default="",
+              help="access key to Testin annotation system, see: http://label.testin.cn/v/secret-key")
 # @click.option("-sk", "--secretKey", 'secret_key', default="")
-@click.option("-h", "--host", 'host', default="http://label.testin.cn/", help="domain name that access to annotation system you would like to operate, default will be: https://label.testin.cn/")
+@click.option(
+    "-h",
+    "--host",
+    'host',
+    default="http://label.testin.cn/",
+    help="domain name that access to annotation system you would like to operate, default will be: https://label.testin.cn/")
 def config(access_key, host):
     """ setting your account """
     configFile = account._config_filepath()
@@ -180,6 +201,7 @@ def config(access_key, host):
             print(conf)
             exit()
 
+
 # @main.command()
 # @click.option("-ds", "--datasetId", 'ds_id', default="", help="the dataset you wolud like to download")
 # @click.option("-save", "--saveDir", 'save_dir', default="", help="save path for downloaded files")
@@ -240,6 +262,7 @@ def config(access_key, host):
 #     if ctx.obj.debug:
 #         print("done!")
 
+
 @main.command()
 @click.pass_context
 def clearcache(ctx):
@@ -252,6 +275,3 @@ def clearcache(ctx):
 
 if __name__ == '__main__':
     main(obj={})
-
-
-
